---
slug: /leave
---

# LEAVE

The `LEAVE` statement exits a labeled control-flow statement. If the label is used for the outermost stored program block, the `LEAVE` statement exits the program.

The syntax of the `LEAVE` statement is as follows:

```sql
LEAVE label
```

The `LEAVE` statement can be used in `BEGIN ... END` blocks and in `LOOP`, `REPEAT`, and `WHILE` loop statements.